//! # checkmate
//!
//! A library for simulating Checkmate games.

pub mod error;
pub mod land;
pub mod map;

pub use error::*;
pub use land::*;
pub use map::*;
